@@ -37,6 +37,7 @@ class TestMetaTypes(TestCaseWithFactory):
     """
     def test_job(self):
         MetaType.objects.all().delete()
+        TestJob.objects.all().delete()
         job = TestJob.from_yaml_and_user(
             self.factory.make_job_yaml(), self.user)
         job_def = yaml.load(job.definition)
@@ -186,6 +187,40 @@ class TestMetaTypes(TestCaseWithFactory):
                 'test.1.definition.path': 'lava-test-shell/single-node/singlenode03.yaml'}
         )
 
+    def test_parameter_support(self):
+        data = self.factory.make_job_data()
+        test_block = [block for block in data['actions'] if 'test' in block][0]
+        smoke = test_block['test']['definitions'][0]
+        smoke['parameters'] = {
+            'VARIABLE_NAME_1': "first variable value",
+            'VARIABLE_NAME_2': "second value"
+        }
+        job = TestJob.from_yaml_and_user(yaml.dump(data), self.user)
+        job_def = yaml.load(job.definition)
+        job_ctx = job_def.get('context', {})
+        device = Device.objects.get(hostname='fakeqemu1')
+        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        parser = JobParser()
+        obj = PipelineDevice(device_config, device.hostname)
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        allow_missing_path(pipeline_job.pipeline.validate_actions, self,
+                           'qemu-system-x86_64')
+        pipeline = pipeline_job.describe()
+        device_values = _get_device_metadata(pipeline['device'])
+        try:
+            testdata, _ = TestData.objects.get_or_create(testjob=job)
+        except (MultipleObjectsReturned):
+            self.fail('multiple objects')
+        for key, value in device_values.items():
+            if not key or not value:
+                continue
+            testdata.attributes.create(name=key, value=value)
+        retval = _get_job_metadata(pipeline['job']['actions'])
+        self.assertIn('test.0.definition.parameters.VARIABLE_NAME_2', retval)
+        self.assertIn('test.0.definition.parameters.VARIABLE_NAME_1', retval)
+        self.assertEqual(retval['test.0.definition.parameters.VARIABLE_NAME_1'], 'first variable value')
+        self.assertEqual(retval['test.0.definition.parameters.VARIABLE_NAME_2'], 'second value')
+
     def test_job_multi(self):
         MetaType.objects.all().delete()
         multi_test_file = os.path.join(os.path.dirname(__file__), 'multi-test.yaml')
@@ -204,3 +239,42 @@ class TestMetaTypes(TestCaseWithFactory):
                            'qemu-system-x86_64')
         pipeline = pipeline_job.describe()
         map_metadata(yaml.dump(pipeline), job)
+
+    def test_inline(self):
+        """
+        Test inline can be parsed without run steps
+        """
+        data = self.factory.make_job_data()
+        test_block = [block for block in data['actions'] if 'test' in block][0]
+        smoke = [
+            {
+                "path": "inline/smoke-tests-basic.yaml",
+                "from": "inline",
+                "name": "smoke-tests-inline",
+                "repository": {
+                    "install": {
+                        "steps": [
+                            "apt",
+                        ]
+                    },
+                    "metadata": {
+                        "description": "Basic system test command for Linaro Ubuntu images",
+                        "format": "Lava-Test Test Definition 1.0",
+                        "name": "smoke-tests-basic"
+                    }
+                }
+            }
+        ]
+        test_block['test']['definitions'] = smoke
+        job = TestJob.from_yaml_and_user(yaml.dump(data), self.user)
+        job_def = yaml.load(job.definition)
+        job_ctx = job_def.get('context', {})
+        device = Device.objects.get(hostname='fakeqemu1')
+        device_config = device.load_device_configuration(job_ctx, system=False)  # raw dict
+        parser = JobParser()
+        obj = PipelineDevice(device_config, device.hostname)
+        pipeline_job = parser.parse(job.definition, obj, job.id, None, None, None, output_dir='/tmp')
+        allow_missing_path(pipeline_job.pipeline.validate_actions, self,
+                           'qemu-system-x86_64')
+        pipeline = pipeline_job.describe()
+        map_metadata(yaml.dump(pipeline), job)
