@@ -258,9 +258,10 @@ class SchedulerAPI(ExposedAPI):
         Return value
         ------------
         This function returns an XML-RPC array in which each item is a list of
-        device hostname, device type, device state and current running job id. For example:
+        device hostname, device type, device state, current running job id and
+        if device is pipeline. For example:
 
-        [['panda01', 'panda', 'running', 164], ['qemu01', 'qemu', 'idle', None]]
+        [['panda01', 'panda', 'running', 164, False], ['qemu01', 'qemu', 'idle', None, True]]
         """
 
         devices_list = []
@@ -271,7 +272,7 @@ class SchedulerAPI(ExposedAPI):
                 continue
             devices_list.append(dev)
 
-        return [list((dev.hostname, dev.device_type.name, Device.STATUS_CHOICES[dev.status][1].lower(), dev.current_job.pk if dev.current_job else None))
+        return [list((dev.hostname, dev.device_type.name, Device.STATUS_CHOICES[dev.status][1].lower(), dev.current_job.pk if dev.current_job else None, dev.is_pipeline))
                 for dev in devices_list]
 
     def all_device_types(self):
@@ -546,6 +547,16 @@ class SchedulerAPI(ExposedAPI):
         ------------
         This function returns an XML-RPC structures of job details, provided
         the user is authenticated with an username and token.
+
+        The elements available in XML-RPC structure include:
+        _results_link, _state, submitter_id, submit_token_id, is_pipeline,
+        id, failure_comment, multinode_definition, user_id, vmgroup_definition,
+        priority, _actual_device_cache, vm_group, original_definition,
+        status, health_check, description, admin_notifications, start_time,
+        target_group, visibility, requested_device_id, pipeline_compatibility,
+        submit_time, is_public, _old_status, actual_device_id, definition,
+        sub_id, requested_device_type_id, _results_bundle_id, end_time,
+        group_id
         """
         self._authenticate()
         if not job_id:
