@@ -41,9 +41,12 @@ default_mapper_urlpatterns = [
 
 token_urlpatterns = [
     url(r'^tokens/$', tokens, name='linaro_django_xmlrpc_tokens'),
-    url(r'^tokens/create/$', create_token),
-    url(r'^tokens/(?P<object_id>\d+)/delete/$', delete_token),
-    url(r'^tokens/delete_unused/$', delete_unused_tokens),
-    url(r'^tokens/(?P<object_id>\d+)/edit/$', edit_token)]
+    url(r'^tokens/create/$', create_token, name='linaro_django_xmlrpc.views.create_token'),
+    url(r'^tokens/(?P<object_id>\d+)/delete/$', delete_token,
+        name='linaro_django_xmlrpc.views.delete_token'),
+    url(r'^tokens/delete_unused/$', delete_unused_tokens,
+        name='linaro_django_xmlrpc.views.delete_unused_tokens'),
+    url(r'^tokens/(?P<object_id>\d+)/edit/$', edit_token,
+        name='linaro_django_xmlrpc.views.edit_token')]
 
 urlpatterns = default_mapper_urlpatterns + token_urlpatterns
